@@ -2,17 +2,12 @@ use utf8;
 use strict;
 use warnings FATAL => 'all';
 
-package Xyzzy::Method::Request;
-
-use Xyzzy::Request -self;
-
-field method => sub { shift->request_method };
-
 package Xyzzy::Method;
 
-use Xyzzy::Handler -self;
-
 use Xyzzy::Fail;
+use Xyzzy::Method::Request;
+
+use Xyzzy::Handler -self;
 
 field methods => {};
 
